.. docubox documentation master file, created by
   sphinx-quickstart on Sun Jan  1 13:45:41 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to docubox's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


   about
   sphinxmod
   mkdocsmod
   authors
   CODE_OF_CONDUCT
   SECURITY
   Changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
